@@ -1,16 +1,17 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.023-7-gfcd9374
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.024-5-g9028a42
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
     'Dist::Zilla::Role::PrereqSource';
 
+use feature 'fc';
 use List::Util 1.33 qw(none any);
 use Git::Wrapper 0.035;
 use Try::Tiny;
@@ -175,7 +176,7 @@ sub _build_contributors
         sub { require Data::Dumper; Data::Dumper->new([ \@contributors ])->Indent(2)->Terse(1)->Dump } ]);
 
     # remove duplicates by email address, keeping the latest associated name
-    @contributors = uniq_by { (/(<[^>]+>)/g)[-1] } @contributors;
+    @contributors = uniq_by { fc((/(<[^>]+>)/g)[-1]) } @contributors;
 
     @contributors = Unicode::Collate->new(level => 1)->sort(@contributors) if $self->order_by eq 'name';
 
@@ -184,13 +185,13 @@ sub _build_contributors
         my @author_emails = map { /(<[^>]+>)/g } @{ $self->zilla->authors };
         @contributors = grep {
             my $contributor = $_;
-            none { $contributor =~ /\Q$_\E/ } @author_emails;
+            none { $contributor =~ /\Q$_\E/i } @author_emails;
         } @contributors;
     }
 
     if (not $self->include_releaser and my $releaser = $self->_releaser)
     {
-        @contributors = grep { $_ ne $releaser } @contributors;
+        @contributors = grep { fc $_ ne fc $releaser } @contributors;
     }
 
     if ($self->remove)
@@ -266,7 +267,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -407,7 +408,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kent Fredric Klaus Eichner Mohammad S Anwar
+=for stopwords Kent Fredric Klaus Eichner Matthew Horsfall Mohammad S Anwar
 
 =over 4
 
@@ -421,6 +422,10 @@ Klaus Eichner <klaus03@gmail.com>
 
 =item *
 
+Matthew Horsfall <wolfsage@gmail.com>
+
+=item *
+
 Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =back
